@@ -1,4 +1,5 @@
 # -*- coding: utf8 -*-
+
 DEBUG = False
 
 DATABASES = {
@@ -8,6 +9,10 @@ DATABASES = {
     }
 }
 
+AUTH_USER_MODEL = 'tests.CustomUser'
+
+LOGIN_CODE_TIMEOUT = 900
+
 INSTALLED_APPS = [
     'django.contrib.auth',
     'django.contrib.contenttypes',
